pub struct Feature(/* private fields */);Expand description
Common device-independent VirtIO device features.
Implementations
Sourceimpl Feature
impl Feature
Sourcepub const NOTIFY_ON_EMPTY: Self
pub const NOTIFY_ON_EMPTY: Self
Legacy: The device must issue a used buffer notification when it runs out of available descriptors, even if notifications are suppressed.
Sourcepub const ANY_LAYOUT: Self
pub const ANY_LAYOUT: Self
Legacy: The device accepts arbitrary descriptor layouts.
Sourcepub const RING_INDIRECT_DESC: Self
pub const RING_INDIRECT_DESC: Self
The device can use descriptors with the indirect flag set.
Sourcepub const RING_EVENT_IDX: Self
pub const RING_EVENT_IDX: Self
The used_event and avail_event fields can be used.
Sourcepub const UNUSED: Self
pub const UNUSED: Self
Legacy: Used by QEMU’s implemenation for experimental early versions of VirtIO which didn’t perform correct feature notification.
Sourcepub const ACCESS_PLATFORM: Self
pub const ACCESS_PLATFORM: Self
The device can be used on a platform where device access to memory is limited or translated.
Sourcepub const RING_PACKED: Self
pub const RING_PACKED: Self
Use packed virtqueue layout.
Sourcepub const IN_ORDER: Self
pub const IN_ORDER: Self
The device uses buffers in the same order that they were made available.
Sourcepub const ORDER_PLATFORM: Self
pub const ORDER_PLATFORM: Self
Memory access by the driver and device are ordered in a way described by the platform.
Sourcepub const NOTIFICATION_DATA: Self
pub const NOTIFICATION_DATA: Self
The driver passes extra data in its device notifications.
Sourceimpl Feature
impl Feature
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Feature
impl Feature
Sourcepub const fn iter(&self) -> Iter<Feature>
pub const fn iter(&self) -> Iter<Feature>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Feature>
pub const fn iter_names(&self) -> IterNames<Feature>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.