VsockEventType

Enum VsockEventType 

pub enum VsockEventType {
    ConnectionRequest,
    Connected,
    Disconnected {
        reason: DisconnectReason,
    },
    Received {
        length: usize,
    },
    CreditRequest,
    CreditUpdate,
}
Available on crate feature alloc only.
Details of the type of an event received from a VirtIO socket.

Variants



ConnectionRequest

The peer requests to establish a connection with us.



Connected

The connection was successfully established.



Disconnected

The connection was closed.

Fields

reason: DisconnectReason

The reason for the disconnection.



Received

Data was received on the connection.

Fields

length: usize

The length of the data in bytes.



CreditRequest

The peer requests us to send a credit update.



CreditUpdate

The peer just sent us a credit update with nothing else.