NotificationType

Enum NotificationType 

#[repr(u32)]
pub enum NotificationType { JackConnected = 4_096, JackDisconnected = 4097, PcmPeriodElapsed = 4_352, PcmXrun = 4353, }
Available on crate feature alloc only.
The notification type.

Variants



JackConnected = 4_096

An external device has been connected to the jack.



JackDisconnected = 4097

An external device has been disconnected from the jack.



PcmPeriodElapsed = 4_352

A hardware buffer period has elapsed, the period size is controlled using the period_bytes field.



PcmXrun = 4353

An underflow for the output stream or an overflow for the inputstream has occurred.