pub struct PcmRates(/* private fields */);Expand description
Supported PCM frame rates.
Implementations
Sourceimpl PcmRates
impl PcmRates
Sourcepub const RATE_11025: Self
pub const RATE_11025: Self
11025 Hz PCM rate.
Sourcepub const RATE_16000: Self
pub const RATE_16000: Self
16000 Hz PCM rate.
Sourcepub const RATE_22050: Self
pub const RATE_22050: Self
22050 Hz PCM rate.
Sourcepub const RATE_32000: Self
pub const RATE_32000: Self
32000 Hz PCM rate.
Sourcepub const RATE_44100: Self
pub const RATE_44100: Self
44100 Hz PCM rate.
Sourcepub const RATE_48000: Self
pub const RATE_48000: Self
48000 Hz PCM rate.
Sourcepub const RATE_64000: Self
pub const RATE_64000: Self
64000 Hz PCM rate.
Sourcepub const RATE_88200: Self
pub const RATE_88200: Self
88200 Hz PCM rate.
Sourcepub const RATE_96000: Self
pub const RATE_96000: Self
96000 Hz PCM rate.
Sourcepub const RATE_176400: Self
pub const RATE_176400: Self
176400 Hz PCM rate.
Sourcepub const RATE_192000: Self
pub const RATE_192000: Self
192000 Hz PCM rate.
Sourcepub const RATE_384000: Self
pub const RATE_384000: Self
384000 Hz PCM rate.
Sourceimpl PcmRates
impl PcmRates
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.