Struct VirtIO9p
Source pub struct VirtIO9p<H: Hal, T: Transport> { }
Driver for a VirtIO 9p device.
Create a new VirtIO 9p driver.
Returns the mount tag reported by the device.
Sends a raw 9p request and waits for the response.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.