BufferDirection

Enum BufferDirection 

pub enum BufferDirection {
    DriverToDevice,
    DeviceToDriver,
    Both,
}
The direction in which a buffer is passed.

Variants



DriverToDevice

The buffer may be read or written by the driver, but only read by the device.



DeviceToDriver

The buffer may be read or written by the device, but only read by the driver.



Both

The buffer may be read or written by both the device and the driver.