read_config

Macro read_config 

macro_rules! read_config {
    ($transport:expr, $struct:ty, $field:ident) => { ... };
}
Reads the given field of the given struct from the device config space via the given transport.