write_config

Macro write_config 

macro_rules! write_config {
    ($transport:expr, $struct:ty, $field:ident, $value:expr) => { ... };
}
Writes the given field of the given struct from the device config space via the given transport.