Module queue

Module queue 

Support for virt queues, the main mechanism for data transport on VirtIO devices.

Types from this module are used to implement VirtIO device drivers. If you just want to use the drivers provided (rather than implementing drivers for other devices) then you shouldn’t need to use anything from this module.

Structs

OwningQueuealloc
A wrapper around VirtQueue that owns all the buffers that are passed to the queue.
VirtQueue
The mechanism for bulk data transport on virtio devices.