pub struct Command(/* private fields */);Expand description
The command register in PCI configuration space.
Implementations
Sourceimpl Command
impl Command
Sourcepub const MEMORY_SPACE: Self
pub const MEMORY_SPACE: Self
The device can respond to Memory Space accesses.
Sourcepub const BUS_MASTER: Self
pub const BUS_MASTER: Self
The device can behave as a bus master.
Sourcepub const SPECIAL_CYCLES: Self
pub const SPECIAL_CYCLES: Self
The device can monitor Special Cycle operations.
Sourcepub const MEMORY_WRITE_AND_INVALIDATE_ENABLE: Self
pub const MEMORY_WRITE_AND_INVALIDATE_ENABLE: Self
The device can generate the Memory Write and Invalidate command.
Sourcepub const VGA_PALETTE_SNOOP: Self
pub const VGA_PALETTE_SNOOP: Self
The device will snoop palette register data.
Sourcepub const PARITY_ERROR_RESPONSE: Self
pub const PARITY_ERROR_RESPONSE: Self
The device should take its normal action when a parity error is detected.
Sourcepub const SERR_ENABLE: Self
pub const SERR_ENABLE: Self
The SERR# driver is enabled.
Sourcepub const FAST_BACK_TO_BACK_ENABLE: Self
pub const FAST_BACK_TO_BACK_ENABLE: Self
The device is allowed to generate fast back-to-back transactions.
Sourcepub const INTERRUPT_DISABLE: Self
pub const INTERRUPT_DISABLE: Self
Assertion of the device’s INTx# signal is disabled.
Sourceimpl Command
impl Command
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.