pub struct Status(/* private fields */);Expand description
The status register in PCI configuration space.
Implementations
Sourceimpl Status
impl Status
Sourcepub const INTERRUPT_STATUS: Self
pub const INTERRUPT_STATUS: Self
The state of the device’s INTx# signal.
Sourcepub const CAPABILITIES_LIST: Self
pub const CAPABILITIES_LIST: Self
The device has a linked list of capabilities.
Sourcepub const MHZ_66_CAPABLE: Self
pub const MHZ_66_CAPABLE: Self
The device is capabile of running at 66 MHz rather than 33 MHz.
Sourcepub const FAST_BACK_TO_BACK_CAPABLE: Self
pub const FAST_BACK_TO_BACK_CAPABLE: Self
The device can accept fast back-to-back transactions not from the same agent.
Sourcepub const MASTER_DATA_PARITY_ERROR: Self
pub const MASTER_DATA_PARITY_ERROR: Self
The bus agent observed a parity error (if parity error handling is enabled).
Sourcepub const SIGNALED_TARGET_ABORT: Self
pub const SIGNALED_TARGET_ABORT: Self
A target device terminated a transaction with target-abort.
Sourcepub const RECEIVED_TARGET_ABORT: Self
pub const RECEIVED_TARGET_ABORT: Self
A master device transaction was terminated with target-abort.
Sourcepub const RECEIVED_MASTER_ABORT: Self
pub const RECEIVED_MASTER_ABORT: Self
A master device transaction was terminated with master-abort.
Sourcepub const SIGNALED_SYSTEM_ERROR: Self
pub const SIGNALED_SYSTEM_ERROR: Self
A device asserts SERR#.
Sourcepub const DETECTED_PARITY_ERROR: Self
pub const DETECTED_PARITY_ERROR: Self
The device detects a parity error, even if parity error handling is disabled.
Sourceimpl Status
impl Status
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.