macro_rules! read_config {
($transport:expr, $struct:ty, $field:ident) => { ... };
}Expand description
Reads the given field of the given struct from the device config space via the given transport.
macro_rules! read_config {
($transport:expr, $struct:ty, $field:ident) => { ... };
}Reads the given field of the given struct from the device config space via the given transport.