macro_rules! write_config {
($transport:expr, $struct:ty, $field:ident, $value:expr) => { ... };
}Expand description
Writes the given field of the given struct from the device config space via the given transport.
macro_rules! write_config {
($transport:expr, $struct:ty, $field:ident, $value:expr) => { ... };
}Writes the given field of the given struct from the device config space via the given transport.