Support for virt queues, the main mechanism for data transport on VirtIO devices.
Types from this module are used to implement VirtIO device drivers. If you just want to use the drivers provided (rather than implementing drivers for other devices) then you shouldn’t need to use anything from this module.
Structs
- Owning
Queue alloc - A wrapper around
VirtQueuethat owns all the buffers that are passed to the queue. - Virt
Queue - The mechanism for bulk data transport on virtio devices.